@@ -1,5 +1,8 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
 
+__version__ = '0.1.0'
+
 from .config import Config
 from .objects import str_object, envvar_object
+from .mappings import json_mapping, yaml_mapping
